Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(932)

Unified Diff: dm/DMUtil.h

Issue 27476007: DM: duh, don't calculate digests unless we're going to look at them. (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: sync and merge Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« dm/DMReplayTask.h ('K') | « dm/DMReplayTask.cpp ('k') | dm/DMUtil.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dm/DMUtil.h
diff --git a/dm/DMUtil.h b/dm/DMUtil.h
index e808ca0f8f4cc730cc72ad3655e954b9e583f1bd..c95f93346a2de425faa9a757b342b52d33707d5e 100644
--- a/dm/DMUtil.h
+++ b/dm/DMUtil.h
@@ -1,6 +1,7 @@
#ifndef DMUtil_DEFINED
#define DMUtil_DEFINED
+#include "SkBitmap.h"
#include "SkString.h"
#include "gm_expectations.h"
@@ -14,9 +15,8 @@ SkString underJoin(const char* a, const char* b);
// png("a") -> "a.png"
SkString png(SkString s);
-// Roughly, expectations.match(digest), but only does it if we're not ignoring the result.
-bool meetsExpectations(const skiagm::Expectations& expectations,
- const skiagm::GmResultDigest& digest);
+// Roughly, expectations.match(GmResultDigest(bitmap)), but calculates the digest lazily.
+bool meetsExpectations(const skiagm::Expectations& expectations, const SkBitmap bitmap);
} // namespace DM
« dm/DMReplayTask.h ('K') | « dm/DMReplayTask.cpp ('k') | dm/DMUtil.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698